@@ -1,6 +1,6 @@
 from video_transformers.auto.backbone import AutoBackbone
 from video_transformers.auto.head import AutoHead
 from video_transformers.auto.neck import AutoNeck
-from video_transformers.modules import TimeDistributed, VideoClassificationModel
+from video_transformers.modeling import TimeDistributed, VideoModel
 
-__version__ = "0.0.3"
+__version__ = "0.0.9"
