@@ -2,6 +2,7 @@ import glob
 import os
 import re
 import urllib.request
+import zipfile
 from pathlib import Path
 
 
@@ -22,8 +23,20 @@ def download_file(url: str, download_path: str):
     """
     Downloads a file from the given url to the given path.
     """
+    Path(download_path).parent.mkdir(parents=True, exist_ok=True)
     if not os.path.exists(download_path):
         print(f"Downloading {url} to {download_path}")
         urllib.request.urlretrieve(url, download_path)
     else:
         print(f"{download_path} already exists. Skipping download.")
+
+
+def download_ucf6(download_folder_path: str):
+    """
+    Downloads the ucf6 dataset to the given folder.
+    """
+    download_url = "https://github.com/fcakyon/video-transformers/releases/download/0.0.2/ucf6.zip"
+    download_path = Path(download_folder_path) / "ucf6.zip"
+    download_file(download_url, download_path)
+    with zipfile.ZipFile(download_path, "r") as zip_ref:
+        zip_ref.extractall(download_folder_path)
